@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -190,9 +198,11 @@ public class FormatData_nl extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_yQQQ = "QQQ y";
         final String metaValue_generic_DateFormatItem_MMMMd = "d MMMM";
         final String metaValue_generic_DateFormatItem_MMMEd = "E d MMM";
+        final String metaValue_generic_DateFormatItem_GyMEd = "E d/M/y G";
         final String metaValue_generic_DateFormatItem_GyMd = "d/M/y GGGGG";
         final String metaValue_generic_DateFormatItem_MMMd = "d MMM";
         final String metaValue_generic_DateFormatItem_MMMMW = "'week' W 'van' MMMM";
+        final String metaValue_generic_DateFormatItem_GyM = "M/y G";
         final String metaValue_generic_DateFormatItem_yMMMEd = "E d MMM y";
         final String metaValue_generic_DateFormatItem_yMEd = "E d-M-y";
         final String metaValue_generic_DateFormatItem_yMMMd = "d MMM y";
@@ -231,6 +241,28 @@ public class FormatData_nl extends ListResourceBundle {
             "Saʻna Hizjria",
         };
         final String metaValue_calendarname_gregorian = "Gregoriaanse kalender";
+        final String[] metaValue_adlm_NumberPatterns = new String[] {
+            "#,##0.###",
+            "¤ #,##0.00",
+            "#,##0%",
+            "",
+        };
+        final String[] metaValue_adlm_NumberElements = new String[] {
+            ".",
+            ",",
+            ";",
+            "%",
+            "0",
+            "#",
+            "-",
+            "E",
+            "‰",
+            "∞",
+            "NaN",
+            "",
+            "",
+            "-－﹣‐‑‒–−⁻₋➖",
+        };
         final String[] metaValue_ListPatterns_or = new String[] {
             "",
             "",
@@ -280,11 +312,13 @@ public class FormatData_nl extends ListResourceBundle {
             { "generic.DateFormatItem.yyyyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "generic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "generic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "generic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "generic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "generic.DateFormatItem.yyyy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.y", metaValue_generic_DateFormatItem_Gy },
+            { "generic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -366,9 +400,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -401,9 +437,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "buddhist.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "buddhist.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "buddhist.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "buddhist.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "buddhist.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "buddhist.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -442,9 +480,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "japanese.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "japanese.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "japanese.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "japanese.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -482,9 +522,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "roc.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "roc.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "roc.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "roc.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "roc.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "roc.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -549,9 +591,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -571,9 +615,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic-civil.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-civil.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-civil.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-civil.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-civil.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic-civil.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -593,9 +639,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic-umalqura.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-umalqura.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-umalqura.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-umalqura.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic-umalqura.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -670,6 +718,655 @@ public class FormatData_nl extends ListResourceBundle {
                     "",
                 }
             },
+            { "adlm.NumberElements", metaValue_adlm_NumberElements },
+            { "adlm.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "arabext.NumberElements",
+                new String[] {
+                    "٫",
+                    "٬",
+                    "؛",
+                    "٪",
+                    "۰",
+                    "#",
+                    "‎-‎",
+                    "×۱۰^",
+                    "؉",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "arabext.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "bali.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᭐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "bali.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "beng.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "০",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "beng.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "brah.NumberElements", metaValue_adlm_NumberElements },
+            { "brah.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "cakm.NumberElements", metaValue_adlm_NumberElements },
+            { "cakm.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "cham.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "꩐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "cham.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "deva.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "०",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "deva.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "fullwide.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "０",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "fullwide.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "gong.NumberElements", metaValue_adlm_NumberElements },
+            { "gong.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "gonm.NumberElements", metaValue_adlm_NumberElements },
+            { "gonm.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "gujr.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "૦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "gujr.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "guru.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "੦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "guru.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "hanidec.NumberElements", metaValue_adlm_NumberElements },
+            { "hanidec.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "java.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "꧐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "java.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "kali.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "꤀",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "kali.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "khmr.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "០",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "khmr.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "knda.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "೦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "knda.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "lana.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᪀",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "lana.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "lanatham.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᪐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "lanatham.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "laoo.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "໐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "laoo.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "lepc.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᱀",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "lepc.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "limb.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᥆",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "limb.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "mlym.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "൦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "mlym.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "mong.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᠐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "mong.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "mtei.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "꯰",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "mtei.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "mymr.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "၀",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "mymr.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "mymrshan.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "႐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "mymrshan.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "nkoo.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "߀",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "nkoo.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "olck.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᱐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "olck.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "orya.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "୦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "orya.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "osma.NumberElements", metaValue_adlm_NumberElements },
+            { "osma.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "rohg.NumberElements", metaValue_adlm_NumberElements },
+            { "rohg.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "saur.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "꣐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "saur.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "shrd.NumberElements", metaValue_adlm_NumberElements },
+            { "shrd.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "sora.NumberElements", metaValue_adlm_NumberElements },
+            { "sora.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "sund.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᮰",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "sund.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "takr.NumberElements", metaValue_adlm_NumberElements },
+            { "takr.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "talu.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "᧐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "talu.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "tamldec.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "௦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "tamldec.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "telu.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "౦",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "telu.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "thai.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "๐",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "thai.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "tibt.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "༠",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "tibt.NumberPatterns", metaValue_adlm_NumberPatterns },
+            { "vaii.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "꘠",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "vaii.NumberPatterns", metaValue_adlm_NumberPatterns },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
