@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -182,6 +190,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "CN", "Chine" },
             { "CO", "Colombie" },
             { "CP", "Île Clipperton" },
+            { "CQ", "Sercq" },
             { "CR", "Costa Rica" },
             { "CU", "Cuba" },
             { "CV", "Cap-Vert" },
@@ -393,7 +402,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "ZA", "Afrique du Sud" },
             { "ZM", "Zambie" },
             { "ZW", "Zimbabwe" },
-            { "ZZ", "région indéterminée" },
+            { "ZZ", "région inconnue" },
             { "aa", "afar" },
             { "ab", "abkhaze" },
             { "ae", metaValue_ae },
@@ -480,7 +489,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "kanouri" },
             { "ks", "cachemiri" },
-            { "ku", "kurde" },
+            { "ku", "kurmandji" },
             { "kv", "komi" },
             { "kw", "cornique" },
             { "ky", "kirghize" },
@@ -1191,10 +1200,13 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "key.cf", "format de devise" },
             { "key.co", "ordre de tri" },
             { "key.cu", "devise" },
+            { "key.em", "Présentation des Emoji" },
             { "key.hc", "système horaire (12 ou 24 heures)" },
             { "key.lb", "style de saut de ligne" },
+            { "key.lw", "Sauts de ligne dans les mots" },
             { "key.ms", "système de mesure" },
             { "key.nu", "nombres" },
+            { "key.ss", "Saut de phrase après une abréviation" },
             { "key.tz", "fuseau horaire" },
             { "key.va", "variante locale" },
             { "nds_NL", "bas-saxon néerlandais" },
@@ -1250,7 +1262,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.nu.java", "chiffres javanais" },
             { "type.nu.jpan", "chiffres japonais" },
             { "type.nu.khmr", "chiffres khmers" },
-            { "type.nu.knda", "chiffres en kannada" },
+            { "type.nu.knda", "chiffres kannadas" },
             { "type.nu.laoo", "chiffres laotiens" },
             { "type.nu.latn", "chiffres occidentaux" },
             { "type.nu.mlym", "chiffres malayâlams" },
@@ -1284,13 +1296,12 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.lb.strict", "style de saut de ligne strict" },
             { "type.m0.ungegn", "UNGEGN" },
             { "type.ms.metric", "système métrique" },
-            { "type.nu.native", "chiffres natifs" },
+            { "type.nu.native", "chiffres locaux" },
             { "type.ca.chinese", "calendrier chinois" },
             { "type.ca.islamic", "calendrier hégirien" },
             { "type.ca.iso8601", "calendrier ISO 8601" },
             { "type.ca.persian", "calendrier persan" },
             { "type.cf.account", "format de devise comptable" },
-            { "type.co.big5han", "ordre chinois traditionnel - Big5" },
             { "type.d0.npinyin", "Numérique" },
             { "type.nu.arabext", "chiffres arabes étendus" },
             { "type.nu.armnlow", "chiffres arméniens minuscules" },
@@ -1299,7 +1310,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.nu.hanidec", "nombres décimaux chinois" },
             { "type.nu.hansfin", "chiffres financiers en chinois simplifié" },
             { "type.nu.hantfin", "chiffres financiers en chinois traditionnel" },
-            { "type.nu.jpanfin", "chiffres japonais financiers" },
+            { "type.nu.jpanfin", "chiffres financiers japonais" },
             { "type.nu.tamldec", "chiffres tamouls" },
             { "type.ca.buddhist", "calendrier bouddhiste" },
             { "type.ca.ethiopic", "calendrier éthiopien" },
@@ -1313,7 +1324,6 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.nu.fullwide", "chiffres pleine chasse" },
             { "type.nu.romanlow", "chiffres romains minuscules" },
             { "type.ca.gregorian", "calendrier grégorien" },
-            { "type.co.gb2312han", "ordre chinois simplifié - GB2312" },
             { "type.co.phonebook", "ordre de l’annuaire" },
             { "ListKeyTypePattern", "{0} : {1}" },
             { "type.co.dictionary", "ordre du dictionnaire" },
