@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -159,6 +167,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "CN", "Sin" },
             { "CO", "Kolambiya" },
             { "CP", "Tsibirin Clipperton" },
+            { "CQ", "Sark" },
             { "CR", "Kwasta Rika" },
             { "CU", "Kyuba" },
             { "CV", "Tsibiran Cape Verde" },
@@ -372,7 +381,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "ZW", "Zimbabuwe" },
             { "ZZ", "Yanki da ba a sani ba" },
             { "ab", "Abkhazian" },
-            { "af", "Afirkanci" },
+            { "af", "Afrikaans" },
             { "ak", "Akan" },
             { "am", "Amharik" },
             { "an", "Aragonesanci" },
@@ -451,7 +460,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "ko", "Harshen Koriya" },
             { "kr", "Kanuri" },
             { "ks", "Kashmiri" },
-            { "ku", "Kurdanci" },
+            { "ku", "Kurmanji" },
             { "kv", "Komi" },
             { "kw", "Cornish" },
             { "ky", "Kirgizanci" },
@@ -514,7 +523,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "sq", "Albaniyanci" },
             { "sr", "Sabiyan" },
             { "ss", "Swati" },
-            { "st", "Sesotanci" },
+            { "st", "Kudancin Sotho" },
             { "su", "Harshen Sundanese" },
             { "sv", "Harshen Suwedan" },
             { "sw", "Harshen Suwahili" },
@@ -562,6 +571,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "ast", "Asturia" },
             { "atj", "Atikamekw" },
             { "awa", "Awadhi" },
+            { "bal", "Baluchi" },
             { "ban", "Balenesanci" },
             { "bas", "Basaa" },
             { "bem", "Bemba" },
@@ -725,7 +735,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "pcm", "Pidgin na Najeriya" },
             { "pis", "Pijin" },
             { "pqm", "Maliseet-Passamaquoddy" },
-            { "prg", "Ferusawa" },
+            { "prg", "Yaren Prussia" },
             { "raj", "Rajasthani" },
             { "rap", "Rapanui" },
             { "rar", "Rarotongan" },
@@ -859,6 +869,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "fa_AF", "Farisanci na Afaganistan" },
             { "fr_CA", "Farasanci Kanada" },
             { "fr_CH", "Farasanci Suwizalan" },
+            { "nl_BE", "Flemish" },
             { "pt_BR", "Harshen Potugis na Birazil" },
             { "pt_PT", "Potugis Ƙasashen Turai" },
             { "ar_001", "Larabci Asali Na Zamani" },
@@ -867,10 +878,13 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "key.cf", "Yanayin Kudi" },
             { "key.co", "Tsarin Rabewa" },
             { "key.cu", "Kudin Kasa" },
+            { "key.em", "Gabatar da Imoji" },
             { "key.hc", "Zagayen Awowi (12 da 24)" },
             { "key.lb", "Salo na Raba Layi" },
+            { "key.lw", "Layi Zai Karye tsakanin Kalmomi" },
             { "key.ms", "Tsarin Awo" },
             { "key.nu", "Lambobi" },
+            { "key.ss", "Jimlar ta Karye Bayan Gajarcewa." },
             { "zh_Hans", "Sauƙaƙaƙƙen Sinanci" },
             { "zh_Hant", "Sinanci na gargajiya" },
             { "type.ca.roc", "Kalandar kasar Sin" },
