@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -250,6 +258,14 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Hawaii = new String[] {
+               "हवाई-एल्यूटियन मानक टाइम",
+               "HST",
+               "",
+               "HST",
+               "",
+               "HST",
+            };
         final String[] Israel = new String[] {
                "इजरायल मानक टाइम",
                "IST",
@@ -466,14 +482,6 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
                "पराग्वे टाइम",
                "",
             };
-        final String[] Sakhalin = new String[] {
-               "सकालिन मानक टाइम",
-               "",
-               "सकालिन समर टाइम",
-               "",
-               "सकालिन टाइम",
-               "",
-            };
         final String[] Suriname = new String[] {
                "सुरीनाम टाइम",
                "",
@@ -562,14 +570,6 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Volgograd = new String[] {
-               "बोल्गोग्राद मानक टाइम",
-               "MSK",
-               "बोल्गोग्राद समर टाइम",
-               "MSK",
-               "बोल्गोग्राद टाइम",
-               "MSK",
-            };
         final String[] Azerbaijan = new String[] {
                "अजरबैजान मानक टाइम",
                "",
@@ -650,14 +650,6 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
                "न्यूजीलैंड टाइम",
                "NZT",
             };
-        final String[] Novosibirsk = new String[] {
-               "नोबोसिबिर्स्क मानक टाइम",
-               "",
-               "नोबोसिबिर्स्क समर टाइम",
-               "",
-               "नोबोसिबिर्स्क टाइप",
-               "",
-            };
         final String[] Philippines = new String[] {
                "फिलिपीन मानक टाइम",
                "PST",
@@ -747,12 +739,12 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
                "EAT",
             };
         final String[] Africa_Western = new String[] {
-               "पश्चिम अफ्रीका मानक टाइम",
-               "WAT",
-               "मध्य अफ्रीका समर टाइम",
-               "WAT",
                "पश्चिम अफ्रीका टाइम",
                "WAT",
+               "",
+               "WAT",
+               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "मध्य यूरोपीय मानक समय",
@@ -830,9 +822,9 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
                "हवाई-एल्यूटियन मानक टाइम",
                "HST",
                "हवाई-एल्यूटियन डेलाइट टाइम",
-               "HST",
+               "HDT",
                "हवाई-एल्यूटियन टाइम",
-               "HST",
+               "HT",
             };
         final String[] Pierre_Miquelon = new String[] {
                "सेंट पिएरे आ मिक्वेलान मानक टाइम",
@@ -913,7 +905,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
-            { "Pacific/Honolulu", Hawaii_Aleutian },
+            { "Pacific/Honolulu", Hawaii },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
@@ -943,7 +935,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "ECT", Europe_Central },
             { "EET", Europe_Eastern },
             { "EST", America_Eastern },
-            { "HST", Hawaii_Aleutian },
+            { "HST", Hawaii },
             { "IET", America_Eastern },
             { "IST", India },
             { "JST", Japan },
@@ -1035,7 +1027,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Greenwich", GMT },
             { "Singapore", Singapore },
             { "US/Alaska", Alaska },
-            { "US/Hawaii", Hawaii_Aleutian },
+            { "US/Hawaii", Hawaii },
             { "Universal",
                 new String[] {
                     "समन्वित वैश्विक समय",
@@ -1055,6 +1047,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "Asia/Tomsk", Krasnoyarsk },
             { "US/Arizona", America_Mountain },
             { "US/Central", America_Central },
             { "US/Eastern", America_Eastern },
@@ -1098,6 +1091,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Asia/Baghdad", Arabian },
             { "Asia/Bahrain", Arabian },
             { "Asia/Bangkok", Indochina },
+            { "Asia/Barnaul", Krasnoyarsk },
             { "Asia/Bishkek", Kyrgystan },
             { "Asia/Colombo", India },
             { "Asia/Irkutsk", Irkutsk },
@@ -1113,6 +1107,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
             { "Canada/Yukon", Yukon },
+            { "Europe/Kirov", Moscow },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1150,7 +1145,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Sakhalin", Sakhalin },
+            { "Asia/Sakhalin", Magadan },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
@@ -1187,7 +1182,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
             { "Pacific/Samoa", Samoa },
-            { "SystemV/HST10", Hawaii_Aleutian },
+            { "SystemV/HST10", Hawaii },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1217,6 +1212,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
             { "Asia/Chungking", China },
+            { "Asia/Famagusta", Europe_Eastern },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
@@ -1329,7 +1325,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Antarctica/Troll", GMT },
             { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
-            { "Asia/Novosibirsk", Novosibirsk },
+            { "Asia/Novosibirsk", Krasnoyarsk },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Vladivostok", Vladivostok },
             { "Atlantic/Bermuda", Atlantic },
@@ -1346,13 +1342,13 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
-            { "Europe/Volgograd", Volgograd },
+            { "Europe/Volgograd", Moscow },
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
             { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston", Hawaii },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
             { "Africa/Nouakchott", GMT },
@@ -1401,6 +1397,7 @@ public class TimeZoneNames_mai extends TimeZoneNamesBundle {
             { "America/St_Vincent", Atlantic },
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
+            { "Asia/Srednekolymsk", Magadan },
             { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
